# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

### Added

### Changed

### Removed


## [0.2.1] 2023-05-04

### Added

- Updated workflow.

### Changed

### Removed

## [0.2.0] - 2023-05-03

### Added

- Initial version.

### Changed

### Removed
